@@ -21,6 +21,6 @@
 ## reset is also done by an observation of all NAs
 setMethod("reset", signature(x = "TRACDS"), function(x) { 
 		x@tracds_d$current_state <- as.character(NA)
-		x
+		invisible(x)
 	}
 )
